"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.port = exports.sequelizeInstance = void 0;
/*
    Set environment variables
*/
require("dotenv/config");
/*
    Sequelize setup
*/
const helper_1 = require("./utils/helper");
// Create instance of sequelize database connection
exports.sequelizeInstance = (0, helper_1.initSequelize)();
exports.port = parseInt(process.env.PORT || "8080");
// Connect to and setup the database
exports.sequelizeInstance
    .authenticate()
    .then(() => {
    (0, database_1.setupDatabase)(exports.sequelizeInstance, process.env.NODE_ENV !== "test").then(() => console.log("Database setup finised"));
})
    .catch((err) => {
    console.error("Unable to connect to the database:", err);
});
const express = require("express");
const cors = require("cors");
const app = express();
app.use(express.json({ limit: "1000mb" }));
app.use(express.urlencoded({
    limit: "1000mb",
    extended: true,
}));
app.use(cors());
/*
    Routing
*/
const users = require("./routes/users.router");
const login = require("./routes/login.router");
const articles = require("./routes/articles.router");
const files = require("./routes/files.router");
const tags = require("./routes/tags.router");
app.use((req, res, next) => {
    console.log(`${req.method} ${req.path}`);
    next();
});
app.use("/users", users.router);
app.use("/login", login.router);
app.use("/files", files.router);
app.use("/tags", tags.router);
app.use("/articles", articles.router);
/*
    ssl setup
*/
const fs = require("fs");
const https = require("https");
const swaggerJsdoc = require("swagger-jsdoc");
const swaggerUi = require("swagger-ui-express");
const database_1 = require("./database/database");
if (process.env.NODE_ENV !== "test") {
    const ssl = {
        key: fs.readFileSync("./certificate/key.pem"),
        cert: fs.readFileSync("./certificate/cert.pem"),
    };
    const httpsServer = https.createServer(ssl, app);
    httpsServer.listen(exports.port);
    console.log("API URL: https://localhost:" + exports.port);
    /*
    Swagger setup
    based on https://github.com/Surnet/swagger-jsdoc/blob/master/examples/app/app.js
*/
    const swaggerEndPoint = "/api-docs/";
    const swaggerDefinition = {
        info: {
            title: "Teaching Articles API",
            swagger: "2.0",
            version: "0.0.1",
            description: "Backend API for fetching and creating articles about programming within different subjects",
        },
        servers: [
            {
                url: "https://localhost:${port}",
            },
        ],
    };
    const swaggerOptions = {
        swaggerDefinition,
        apis: ["./src/*/*.ts", "./outdir/*/*.js"],
    };
    const swaggerSpec = swaggerJsdoc(swaggerOptions);
    app.use(swaggerEndPoint, swaggerUi.serve, swaggerUi.setup(swaggerSpec));
    console.log("API Doc: https://localhost:" + exports.port + swaggerEndPoint);
}
