"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.remove = exports.update = exports.create = exports.get = exports.getAll = void 0;
const formidable = require("formidable");
const articleService = require("../services/article.service");
async function getAll(req, res) {
    const searchString = req.query.search?.toString();
    articleService
        .getAll(searchString)
        .then((articles) => {
        res.status(200).json(articles);
    })
        .catch((err) => {
        console.error("Error while getting all articles:", err);
        res.status(500).end(err);
    });
}
exports.getAll = getAll;
async function get(req, res) {
    articleService
        .get(parseInt(req.params.id))
        .then((article) => {
        res.status(200).json(article);
    })
        .catch((err) => {
        console.error("Error while getting article:", err);
        res.status(500).end(err);
    });
}
exports.get = get;
async function create(req, res) {
    const form = formidable({
        multiples: true,
        uploadDir: "./artifacts",
        keepExtensions: true,
    });
    form.parse(req, (err, fields, files) => {
        const bodyString = fields?.body;
        const body = JSON.parse(bodyString);
        const articleFiles = [];
        if (files?.file) {
            if (typeof files?.file?.map === "function") {
                files?.file
                    ?.map((x) => {
                    return {
                        id: "",
                        hash: x.path.slice(10),
                        name: x.name ?? "",
                        altText: undefined,
                    };
                })
                    .forEach((x) => articleFiles.push(x));
            }
            else {
                const x = files?.file;
                articleFiles.push({
                    id: "",
                    hash: x.path.slice(10),
                    name: x.name ?? "",
                    altText: undefined,
                });
            }
        }
        if (files?.thumbnail) {
            const thumbnail = files?.thumbnail;
            articleFiles.push({
                id: "",
                hash: thumbnail.path.slice(10),
                name: thumbnail.name ?? "",
                altText: "Thumbnail for article",
            });
        }
        if (!body.authorId) {
            console.error("Missing authorId when creating article");
            res.status(400).end("Missing authorId");
            return;
        }
        articleService
            .create(body.title, body.description, body.authorId, body.Tags, articleFiles)
            .then(async (article) => {
            res.status(200).json(article);
        })
            .catch((err) => {
            console.error("Error while creating article:", err);
            res.status(500).end(err);
        });
    });
}
exports.create = create;
async function update(req, res) {
    const form = formidable({
        multiples: true,
        uploadDir: "./artifacts",
        keepExtensions: true,
    });
    form.parse(req, (err, fields, files) => {
        const bodyString = fields?.body;
        const body = JSON.parse(bodyString);
        const articleFiles = [];
        if (files?.file) {
            if (typeof files?.file?.map === "function") {
                files?.file
                    ?.map((x) => {
                    return {
                        id: "",
                        hash: x.path.slice(10),
                        name: x.name ?? "",
                        altText: undefined,
                    };
                })
                    .forEach((x) => articleFiles.push(x));
            }
            else {
                const x = files?.file;
                articleFiles.push({
                    id: "",
                    hash: x.path.slice(10),
                    name: x.name ?? "",
                    altText: undefined,
                });
            }
        }
        if (files?.thumbnail) {
            const thumbnail = files?.thumbnail;
            articleFiles.push({
                id: "",
                hash: thumbnail.path.slice(10),
                name: thumbnail.name ?? "",
                altText: "Thumbnail for article",
            });
        }
        if (!body.authorId) {
            console.error("Missing authorId when creating article");
            res.status(400).end("Missing authorId");
            return;
        }
        articleService
            .update(parseInt(req.params.id), body.title, body.description, body.Tags, articleFiles)
            .then((article) => {
            res.status(200).json(article);
        })
            .catch((err) => {
            console.error("Error while updating article:", err);
            res.status(500).end(err);
        });
    });
}
exports.update = update;
async function remove(req, res) {
    articleService
        .remove(req.params.id)
        .then((articleId) => {
        res.status(200).json(articleId);
    })
        .catch((err) => {
        console.error("Error while deleting article:", err);
        res.status(500).end(err);
    });
}
exports.remove = remove;
