"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getUserArticles = exports.update = exports.get = exports.getAllUsers = exports.create = void 0;
const userService = require("../services/user.service");
const articleService = require("../services/article.service");
async function create(req, res) {
    if (!req.body.username || !req.body.email || !req.body.password) {
        res.status(400).end("Missing username, email, or password");
        return;
    }
    userService
        .create(req.body.username, req.body.email, req.body.password)
        .then((user) => {
        res.status(200).json(user);
    })
        .catch((err) => {
        console.error("Error while creating user:", err);
        res.status(500).end(err);
    });
}
exports.create = create;
async function getAllUsers(req, res) {
    userService
        .getAllUsers()
        .then((users) => {
        res.status(200).json(users);
    })
        .catch((err) => {
        console.error("Error while getting all users:", err);
        res.status(500).end(err);
    });
}
exports.getAllUsers = getAllUsers;
async function get(req, res) {
    if (!req.params.id) {
        console.error("Error while getting user: Missing userId");
        res.status(400).end("Missing userId");
    }
    userService
        .get(req.params.id)
        .then((user) => {
        res.status(200).json(user);
    })
        .catch((err) => {
        console.error("Error while getting user:", err);
        res.status(500).end(err);
    });
}
exports.get = get;
async function update(req, res) {
    userService
        .update(req.params.id, req.body.newUsername, req.body.newEmail, req.body?.newPassword)
        .then((user) => {
        res.status(200).json(user);
    })
        .catch((err) => {
        console.error("Error while updating user:", err);
        res.status(500).end(err);
    });
}
exports.update = update;
async function getUserArticles(req, res) {
    if (!req.params.id) {
        console.error("Error while getting user articles: Missing userId");
        res.status(400).end("Missing userId");
    }
    articleService
        .getArticlesByUserId(req.params.id)
        .then((articles) => {
        res.status(200).json(articles);
    })
        .catch((err) => {
        console.error("Error while getting user articles:", err);
        res.status(400).end(err);
    });
}
exports.getUserArticles = getUserArticles;
