"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupDatabase = void 0;
const Article_model_1 = require("./models/Article.model");
const File_model_1 = require("./models/File.model");
const User_model_1 = require("./models/User.model");
const Tag_model_1 = require("./models/Tag.model");
async function setupDatabase(sequelize, logging = false) {
    //models
    // Article 1:m
    File_model_1.File.belongsTo(Article_model_1.Article, { foreignKey: "articleId" });
    Article_model_1.Article.hasMany(File_model_1.File, { foreignKey: "articleId" });
    // User 1:m
    Article_model_1.Article.belongsTo(User_model_1.User, { foreignKey: "authorId" });
    User_model_1.User.hasMany(Article_model_1.Article, { foreignKey: "authorId" });
    // Article Tag n:m
    Article_model_1.Article.belongsToMany(Tag_model_1.Tag, {
        through: "TagArticle",
        timestamps: false,
    });
    Tag_model_1.Tag.belongsToMany(Article_model_1.Article, {
        through: "TagArticle",
        timestamps: false,
    });
    // mock-data
    await sequelize
        .sync({ force: process.env.DATABASE_FORCE_UPDATE == "true" })
        .then(async () => {
        if (process.env.SERVER_TEST_DATA == "true") {
            if (logging)
                console.info("Adding mock data to the database");
            const dataUser = require("./mock/userMock.json");
            for (let userNumber in dataUser) {
                await User_model_1.User.create(dataUser[userNumber]).catch((error) => console.error(error));
            }
            if (logging)
                console.info("Adding Article data");
            const articleData = require("./mock/articleMock.json");
            for (let articleNumber in articleData) {
                await Article_model_1.Article.create(articleData[articleNumber]).catch((error) => console.error(error));
            }
            if (logging)
                console.info("Adding Tag data");
            const tagData = require("./mock/tagMock.json");
            for (let tag of tagData.tags) {
                await Tag_model_1.Tag.create({
                    name: tag.name,
                    tagType: tag.tagType,
                }).catch((error) => console.error(error));
            }
            if (logging)
                console.info("Adding TagArticle data");
            const tagArticleData = require("./mock/tagArticleMock.json");
            for (let tagArticle of tagArticleData.tagArticles) {
                await sequelize
                    .model("TagArticle")
                    .create(tagArticle)
                    .catch((error) => console.error(error));
            }
            if (logging)
                console.info("Adding File data");
            const fileData = require("./mock/fileMock.json");
            let i = 0;
            for (let file of fileData.files) {
                i++;
                await File_model_1.File.create({ id: i, ...file }).catch((error) => console.error(error));
            }
        }
    })
        .then(() => {
        return;
    });
}
exports.setupDatabase = setupDatabase;
