"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.update = exports.create = exports.getAllUsers = exports.get = exports.login = void 0;
const User_model_1 = require("../database/models/User.model");
const helper_1 = require("../utils/helper");
async function login(email, password) {
    return new Promise(async (res, error) => {
        const user = await User_model_1.User.findOne({
            where: { email: email },
        });
        if (!user) {
            error("Incorrect password or email");
            return;
        }
        if (user.comparePassword(password)) {
            res(user.getDto());
        }
        else {
            error("Incorrect password or email");
        }
        return;
    });
}
exports.login = login;
async function get(userId) {
    return new Promise(async (res, error) => {
        const user = await User_model_1.User.findByPk(userId);
        if (!user) {
            error("Could not find user");
            return;
        }
        res(user.getDto());
    });
}
exports.get = get;
async function getAllUsers() {
    return new Promise(async (res, error) => {
        const users = await User_model_1.User.findAll();
        res(users.map((x) => x.getDto()));
    });
}
exports.getAllUsers = getAllUsers;
async function create(username, email, password) {
    return new Promise(async (res, error) => {
        const usernameCheck = await User_model_1.User.findAndCountAll({
            where: {
                username: username,
            },
        });
        if (usernameCheck.count) {
            error("Username already taken");
            return;
        }
        const emailCheck = await User_model_1.User.findAndCountAll({
            where: { email: email },
        });
        if (emailCheck.count) {
            error("Email already in use");
            return;
        }
        const user = await User_model_1.User.create({
            id: (0, helper_1.getRandomString)(),
            username: username,
            email: email,
            password: password,
            roleId: 0,
            verified: true,
        });
        res(user.getDto());
    });
}
exports.create = create;
async function update(userId, newUsername, newEmail, newPassword) {
    return new Promise(async (res, error) => {
        if (newPassword) {
            await User_model_1.User.update({
                username: newUsername,
                email: newEmail,
                password: newPassword,
            }, {
                where: { id: userId },
            });
        }
        else {
            await User_model_1.User.update({
                username: newUsername,
                email: newEmail,
            }, {
                where: { id: userId },
            });
        }
        const updatedUser = await User_model_1.User.findByPk(userId);
        if (!updatedUser) {
            error("Could not get user after updating");
            return;
        }
        res(updatedUser.getDto());
    });
}
exports.update = update;
